package org.jboss.docs.fd.client;

import org.jboss.docs.fd.ejb.manager.ManagerSession;
import org.jboss.docs.fd.ejb.manager.ManagerSessionHome;

import javax.naming.InitialContext;
import javax.naming.Context;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;
import java.util.Hashtable;

/**
 * Client class to test converted beans.
 *
 * @author <a href="mailto:aloubyansky@hotmail.com">Alex Loubyansky</a>
 */
public class Client
{
   // Constants ---------------------------------------------
   static final String MANAGER_JNDI = "ManagerSession";

   // Attributes --------------------------------------------
   static String INITIAL_CONTEXT_FACTORY;
   static String PROVIDER_URL;
   static String URL_PKG_PREFIXES;

   // main --------------------------------------------------
   public static void main( String[] args )
   {
      if( args.length > 0 )
      {
         INITIAL_CONTEXT_FACTORY = args[ 0 ];
         System.out.println( "java.naming.factory.initial=" + INITIAL_CONTEXT_FACTORY );
      }
      if( args.length > 1 )
      {
         PROVIDER_URL = args[ 1 ];
         System.out.println( "java.naming.provider.url=" + PROVIDER_URL );
      }
      if( args.length > 2 )
      {
         URL_PKG_PREFIXES = args[ 2 ];
         System.out.println( "java.naming.factory.url.pkgs=" + URL_PKG_PREFIXES );
      }

      try
      {
         Client client = new Client();
         client.test();
      }
      catch( Exception e )
      {
         System.out.println( "test failed: " );
         e.printStackTrace();
      }
   }

   // Constructor --------------------------------------------
   public Client() { }

   // Private ------------------------------------------------
   private void test()
      throws Exception
   {
      // look up for ManagerSessionHome
      System.out.println( "looking up for " + MANAGER_JNDI );
      Context ic = getInitialContext();
      Object managerRef = ic.lookup( MANAGER_JNDI );
      if( managerRef == null )
         throw new Exception( MANAGER_JNDI + " not found" );

      // create an instance of ManagerSession bean
      ManagerSessionHome managerHome = (ManagerSessionHome)
         PortableRemoteObject.narrow( managerRef, ManagerSessionHome.class );
      System.out.println( "creating an instance of ManagerSessionEJB" );
      ManagerSession manager = managerHome.create();

      // clean the data source
      System.out.println( "cleaning the database" );
      manager.cleanDataSource();

      // create teacher info
      System.out.println( "creating teachers:" );
      String teachers[] = { "Smirnoff", "Nemiroff" };
      for( int i = 0; i < teachers.length; ++i )
      {
         manager.createTeacherInfo( teachers[i] );
         System.out.println( "created teacher: " + teachers[i] );
      }

      // create group info
      String deptId = "KV";
      Long groups[] = { new Long(61), new Long(62) };
      System.out.println( "creating groups:" );
      for( int i = 0; i < groups.length; ++i )
      {
         String description = "Specialized Computer Systems group no."
            + deptId + groups[i];
         manager.createGroupInfo( deptId, groups[i], description );
         System.out.println( "created group: "
            + deptId + '-' + groups[i] + ',' + description );
      }

      // create student info
      String students[] = { "Ivanov", "Petrov", "Sidorov" };
      System.out.println( "creating students: " );
      for( int i = 0, j = 0; i < students.length; ++i, ++j )
      {
         if( j >= groups.length ) j = 0;
         manager.createStudentInfo( students[i], deptId, groups[j] );
         System.out.println( "added student " + students[i]
            + " to group " + deptId + '-' + groups[j]);
      }

      // add groups to teacher
      System.out.println( "assigning groups to teachers" );
      for( int i = 0, j = 0; i < teachers.length; ++i, ++j )
      {
         if( j >= groups.length ) j = 0;
         manager.addGroupToTeacher( teachers[i], deptId, groups[j] );
         System.out.println( "group " + deptId + '-' + groups[j]
            + " assigned to teacher " + teachers[i] );
      }

      // fetch students for teacher
      for( int i = 0; i < teachers.length; ++i )
      {
         System.out.println( "students for teacher " + teachers[ i ] + ": "
            + manager.getStudentsForTeacher( teachers[ i ] ) );
      }

      System.out.println( "students for teacher Egoroff: "
         + manager.getStudentsForTeacher( "Egoroff" ) );
   }

   private Context getInitialContext()
      throws NamingException
   {
      Hashtable props = new Hashtable();
      if( INITIAL_CONTEXT_FACTORY != null )
         props.put( Context.INITIAL_CONTEXT_FACTORY, INITIAL_CONTEXT_FACTORY );
      if( PROVIDER_URL != null )
         props.put( Context.PROVIDER_URL, PROVIDER_URL );
      if( URL_PKG_PREFIXES != null )
         props.put( Context.URL_PKG_PREFIXES, URL_PKG_PREFIXES );
      if( !props.isEmpty() )
         return new InitialContext( props );
      else
         return new InitialContext();
   }
}
