/*
 * Interactive Media
 */
package org.jboss.docs.fd.ejb.group;

import javax.ejb.EntityBean;
import javax.ejb.CreateException;
import javax.ejb.EntityContext;
import javax.ejb.RemoveException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.naming.NamingException;
import javax.naming.InitialContext;
import java.util.Collection;
import java.util.Iterator;

/**
 * Local entity bean models a group of students.
 *
 * @ejb.bean
 *    name="Group"
 *    display-name="Group EJB"
 *    generate="true"
 *    local-jndi-name="fd/sample/Group"
 *    view-type="local"
 *    type="CMP"
 *    reentrant="False"
 *    cmp-version="2.x"
 *
 * @ejb.pk generate="true"
 *
 * @ejb.finder
 *    view-type="local"
 *    signature="Collection findAll()"
 *    query="SELECT OBJECT(g) FROM Group AS g"
 *
 * @ejb.transaction type="Required"
 *
 * @ejb.persistence table-name="groups"
 *
 * @jboss.create-table "${jboss.create.table}"
 * @jboss.remove-table "${jboss.remove.table}"
 *
 * @author <a href="mailto:aloubyansky@hotmail.com">Alex Loubyansky</a>
 */
public abstract class GroupEJB
   implements EntityBean
{
   // Attributes ---------------------------------------------------------
   private EntityContext ctx;

   // CMP accessors ------------------------------------------------------
   /**
    * Group's department id: primary key field
    *
    * @ejb.persistent-field
    * @ejb.pk-field
    *
    * @ejb.persistence
    *    column-name="dept_id"
    *    jdbc-type="VARCHAR"
    *    sql-type="VARCHAR(5)"
    *
    * @ejb.interface-method
    */
   public abstract String getDepartmentId();
	public abstract void setDepartmentId(String departmentId);

   /**
    * Group's number: primary key field
    *
    * @ejb.persistent-field
    * @ejb.pk-field
    *
    * @ejb.persistence
    *    column-name="group_no"
    *    jdbc-type="INTEGER"
    *    sql-type="INTEGER(5)"
    *
    * @ejb.interface-method
    */
   public abstract Long getGroupNo();
	public abstract void setGroupNo(Long groupNo);

   /**
    * Group description: persistent field
    *
    * @ejb.persistent-field
    *
    * @ejb.persistence
    *    column-name="description"
    *    jdbc-type="VARCHAR"
    *    sql-type="VARCHAR(200)"
    *
    * @ejb.interface-method
    */
   public abstract String getDescription();
   /**
    * @ejb.interface-method
    */
   public abstract void setDescription(String description);

   // CMR accessors -------------------------------------------------------

   /**
    * Student - Group: many-to-one bidirectional
    *
    * @ejb.interface-method
    *
    * @ejb.relation
    *    name="Student-Group"
    *    role-name="Group-has-Students"
    */
   public abstract Collection getStudents();
   /**
    * @ejb.interface-method
    */
   public abstract void setStudents( Collection students );

   /**
    * Teacher - Group: many-to-many bidirectional
    *
    * @ejb.interface-method
    *
    * @ejb.relation
    *    name="Teacher-Group"
    *    role-name="Group-has-Teachers"
    *
    * @jboss.relation-table
    *    table-name="teacher_group"
    *    create-table="${jboss.create.table}"
    *    remove-table="${jboss.remove.table}"
    * @jboss.relation
    *    fk-constraint="false"
    *    related-pk-field="teacherId"
    *    fk-column="teacher_id_fk"
    *
    * @weblogic.relation join-table-name="teacher_group"
    * @weblogic.column-map
    *    foreign-key-column="group_no_fk"
    *    key-column="group_no"
    * @weblogic.column-map
    *    foreign-key-column="dept_id_fk"
    *    key-column="dept_id"
    */
   public abstract Collection getTeachers();
   /**
    * @ejb.interface-method
    */
   public abstract void setTeachers( Collection teachers );

   // EntityBean implementation -------------------------------------------
   /**
    * @ejb.create-method
    */
   public GroupPK ejbCreate( String deptId, Long groupNo, String description )
      throws CreateException
	{
      this.setDepartmentId( deptId );
      this.setGroupNo( groupNo );
      this.setDescription( description );
		return null;
	}

   public void ejbPostCreate( String deptId, Long groupNo, String description ) {}

   public void setEntityContext(EntityContext ctx)
   {
      this.ctx = ctx;
   }

	public void unsetEntityContext() {}

	public void ejbActivate() {}
	public void ejbLoad() {}
	public void ejbPassivate() {}
	public void ejbRemove() throws RemoveException {}
	public void ejbStore() {}
}
