package org.jboss.docs.fd.ejb.sequence;

import java.rmi.RemoteException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.EJBException;
import javax.ejb.CreateException;
import javax.ejb.RemoveException;

/**
 * Local entity bean models a sequence table.
 *
 * @ejb.bean
 *    name="Sequence"
 *    display-name="Sequence EJB"
 *    generate="true"
 *    local-jndi-name="fd/sample/Sequence"
 *    view-type="local"
 *    type="CMP"
 *    reentrant="False"
 *    cmp-version="2.x"
 *    primkey-field="name"
 *
 * @ejb.util generate="logical"
 *
 * @ejb.pk class="java.lang.String" generate="false"
 *
 * @ejb.transaction type="RequiresNew"
 *
 * @ejb.persistence table-name="sequences"
 *
 * @jboss.create-table "${jboss.create.table}"
 * @jboss.remove-table "${jboss.remove.table}"
 *
 * @author <a href="mailto:aloubyansky@hotmail.com">Alex Loubyansky</a>
 */
public abstract class SequenceEJB
   implements EntityBean
{
   // CMP accessors ------------------------------------------------------
   /**
    * Sequence name: primary key field
    *
    * @ejb.persistent-field
    * @ejb.pk-field
    *
    * @ejb.persistence
    *    column-name="name"
    *    jdbc-type="VARCHAR"
    *    sql-type="VARCHAR(50)"
    */
   public abstract String getName();
	public abstract void setName(java.lang.String name);

   /**
    * Sequence index: persistent field
    *
    * @ejb.persistent-field
    *
    * @ejb.persistence
    *    column-name="seqIndex"
    *    jdbc-type="INTEGER"
    *    sql-type="INTEGER"
    */
   public abstract int getIndex();
   public abstract void setIndex(int index);

   // Business methods ----------------------------------------------------
   /**
    * @ejb.interface-method
    */
   public int getValueAfterIncrementingBy(int blockSize)
	{
      this.setIndex(this.getIndex() + blockSize);
		return this.getIndex();
	}

   // EntityBean implementation -------------------------------------------
   /**
    * @ejb.create-method
    */
   public String ejbCreate(String name)
      throws CreateException
	{
		this.setName(name);
		this.setIndex(0);
		return null;
	}

   public void ejbPostCreate(String name) {}
   public void setEntityContext(EntityContext unused) {}
	public void unsetEntityContext() {}

	public void ejbActivate() {}
	public void ejbLoad() {}
	public void ejbPassivate() {}
	public void ejbRemove() throws RemoveException {}
	public void ejbStore() {}
}
